/***********************************************************************/
/***********************************************************************/
/**                                                              
/** Copyright (C) BEKA Associates Ltd (2005). All Rights Reserved    
/**                                                                   
/** Device        : BA488CF                              
/** Communication : PROFIBUS PA                                       
/** Description   : PROFIBUS PA EDDL for BA488CF  		 
/**  		    Physical Block Varaibles and Commands            
/**
/** Histrory      : M.P.Wilson 04/03/2005 first created
/**		    M.P.Wilson 08/03/2005 Manufacturers ID Added
/**		    M.P.Wilson 29/04/2005 View of Blocks Added 
/**
/***********************************************************************/
/***********************************************************************/

/***********************************************************************/
/*****  Variables Physical Block												   */
/***********************************************************************/

VARIABLE phys_BLK_RESERVE
{
	LABEL		[blk_reserved];
	HELP		[blk_reserved_help];
	CLASS		CONTAINED;
  	TYPE		ENUMERATED(1)
	{
		DEFAULT_VALUE	250;
		{	250,	[not_used]		}
	}
	HANDLING	READ;
}

VARIABLE phys_BLK_OBJECT
{
	LABEL		[blk_block_object];
	HELP		[blk_block_object_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	1;
		{	1,	[blk_block_object_PHYSICAL]	}
	}
	HANDLING	READ;
}

VARIABLE phys_BLK_PARENT_CLASS
{
	LABEL		[blk_parent_class];
	HELP		[phys_blk_parent_class_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED(1)
	{
		DEFAULT_VALUE	1;
		{	1,	[phys_blk_parent_class_TRANSMITTER]	}
	}
	HANDLING	READ;
}

VARIABLE phys_BLK_CLASS
{
	LABEL		[blk_class];
	HELP		[phys_blk_class_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED(1)
	{
		DEFAULT_VALUE	250;
		{	250,	[not_used]		}
	}
	HANDLING	READ;
}

VARIABLE phys_BLK_DD_REFRENCE
{
	LABEL		[blk_dd_reference];
	HELP		[blk_dd_reference_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (4);
	HANDLING	READ;
}

VARIABLE phys_BLK_DD_REV
{
	LABEL		[blk_dd_rev];
	HELP		[blk_dd_rev_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER(2);
	HANDLING	READ;
}

VARIABLE phys_BLK_PROFILE
{
	LABEL		[blk_profile];
	HELP		[blk_profile_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	0x4002;
		{ 0x4001,	[blk_profile_PA_COMPACT_A]	},
		{ 0x4002,	[blk_profile_PA_COMPACT_B]	},
		{ 0x4081,	[blk_profile_PA_SIMPLE_A]	},
		{ 0x4082,	[blk_profile_PA_SIMPLE_B]	}
	}
	HANDLING	READ;
}

VARIABLE phys_BLK_PROFILE_REV
{
	LABEL		[blk_profile_rev];
	HELP		[blk_profile_rev_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	0x0300;
		{	0x0300,	"3.0"	}
	}
	HANDLING	READ;
}

VARIABLE phys_BLK_EXECUTION_TIME
{
	LABEL		[blk_execution_time];
	HELP		[blk_execution_time_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER(1)
	{
		DEFAULT_VALUE	0;
	}
	HANDLING	READ;
}

VARIABLE phys_BLK_NUM_PARAMETERS
{
	LABEL		[blk_num_parameters];
	HELP		[blk_num_parameters_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
}

VARIABLE phys_BLK_INDEX_VIEW_1
{
	LABEL		[blk_index_view_1];
	HELP		[blk_index_view_1_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
}

VARIABLE phys_BLK_NUM_VIEW_LISTS
{
	LABEL		[blk_num_view_lists];
	HELP		[blk_num_view_lists_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ;
}

VARIABLE phys_STATIC_REVISION
{
	LABEL		[st_rev];
	HELP		[st_rev_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE	0;
	}
	HANDLING	READ;
}

VARIABLE phys_TAG_DESCRIPTION
{
	LABEL		[tag_desc];		
	HELP		[tag_desc_help];
	CLASS		CONTAINED;
	TYPE		ASCII (32)
	{
		DEFAULT_VALUE "BEKA Associates";
	}
	HANDLING	READ & WRITE;
}

VARIABLE phys_STRATEGY
{
	LABEL		[strategy];		
	HELP		[strategy_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ & WRITE;
}

VARIABLE phys_ALERT_KEY
{
	LABEL		[alert_key];		
	HELP		[alert_key_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ & WRITE;
}

VARIABLE phys_TARGET_MODE
{
	LABEL	  	[target_mode];		
	HELP		[target_mode_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
	   DEFAULT_VALUE	0x08;
		{	0x08,	[mode_AUTO]				}	//,
//		{	0x10,	[mode_MAN]				},
		{	0x80,	[mode_OUT_OF_SERVICE]	}

	}
	HANDLING	READ & WRITE;
}

VARIABLE phys_ACTUAL_MODE
{
	LABEL		[actual_mode];		
	HELP		[actual_mode_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE 0x08 ;
//		{	0x02,	[mode_RCAS]				},
		{	0x08,	[mode_AUTO]				}
//		{	0x10,	[mode_MAN]				},
//		{	0x20,	[mode_LO]				},
		{	0x80,	[mode_OUT_OF_SERVICE]	}
	}
	HANDLING	READ;
}

VARIABLE phys_PERMITTED_MODE
{
	LABEL		[permitted_mode];		
	HELP		[permitted_mode_help];
	CLASS		CONTAINED;
	TYPE		BIT_ENUMERATED (1)
	{
		DEFAULT_VALUE	0x08;
//		{	0x02,	[mode_RCAS]				},
		{	0x08,	[mode_AUTO]				}
//		{	0x10,	[mode_MAN]				},
//		{	0x20,	[mode_LO]				},
		{	0x80,	[mode_OUT_OF_SERVICE]	}
	}
	HANDLING	READ;
}

VARIABLE phys_NORMAL_MODE
{
	LABEL		[normal_mode];		
	HELP		[normal_mode_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0x08;
		{	0x02,	[mode_RCAS]				},
		{	0x08,	[mode_AUTO]				},
		{	0x10,	[mode_MAN]				},
		{	0x20,	[mode_LO]				},
		{	0x80,	[mode_OUT_OF_SERVICE]	}
	}
	HANDLING	READ;
}

VARIABLE phys_CURRENT_STATE_ALARM_SUM
{
	LABEL		[current_state_alarm_sum];		
	HELP		[current_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		DEFAULT_VALUE	0x0000; 
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE phys_UNACKNOWLEDGED_STATE_ALARM_SUM
{
	LABEL		[unacknowledged_state_alarm_sum];		
	HELP		[unacknowledged_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		DEFAULT_VALUE	0x0000; 
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE phys_UNREPORTED_STATE_ALARM_SUM
{
	LABEL		[unreported_state_alarm_sum];		
	HELP		[unreported_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		DEFAULT_VALUE	0x0000; 
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE phys_DISABLED_STATE_ALARM_SUM
{
	LABEL		[disabled_state_alarm_sum];		
	HELP		[disabled_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		DEFAULT_VALUE	0x0000; 
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE phys_SOFTWARE_REVISION
{
	LABEL		[phys_software_revision];
	HELP		[phys_software_revision_help];
	CLASS		CONTAINED;
	TYPE		ASCII (16)
	{
		DEFAULT_VALUE "1.00";
	}
	HANDLING	READ;
}

VARIABLE phys_HARDWARE_REVISION
{
	LABEL		[phys_hardware_revision];
	HELP		[phys_hardware_revision_help];
	CLASS		CONTAINED;
	TYPE		ASCII (16)
	{
		DEFAULT_VALUE "1.00";
	}
	HANDLING	READ;
}

VARIABLE phys_DEVICE_MAN_ID
{
	LABEL		[phys_device_man_id];
	HELP		[phys_device_man_id_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	280;
		{ 1,   [Acromag]				},
		{ 2,   [Allen_Bradley]				},
		{ 3,   [Ametek]					},
		{ 4,   [Analog_Devices]				},
		{ 5,   [Elsag_Bailey]				},
		{ 6,   [Beckman]				},
		{ 7,   [Bell_Microsensor]			},
		{ 8,   [Bourns]					},
		{ 9,   [Bristol_Babcock]			},
		{ 10,  [Brooks_Instrument]			},
		{ 11,  [Chessell]				},
		{ 12,  [Combustion_Engineering]			},
		{ 13,  [Daniel_Industries]			},
		{ 14,  [Delta]					},
		{ 15,  [Dieterich_Standard]			},
		{ 16,  [Dohrmann]				},
		{ 17,  [Endress_and_Hauser]			},
		{ 18,  [Elsag_Bailey]				},
		{ 19,  [Fisher_Controls]			},
		{ 20,  [Foxboro]				},
		{ 21,  [Fuji]					},
		{ 22,  [Elsag_Bailey]				},
		{ 23,  [Honeywell]				},
		{ 24,  [ITT_Barton]				},
		{ 25,  [KayRay_Sensall]				},
		{ 26,  [Kent]					},
		{ 27,  [Leeds_and_Northrup]			},
		{ 28,  [Leslie]					},
		{ 29,  [M_System_Co]				},
		{ 30,  [Measurex]				},
		{ 31,  [Micro_Motion]				},
		{ 32,  [Moore_Industries]			},
		{ 33,  [Moore_Products]				},
		{ 34,  [Ohkura_Electric]			},
		{ 35,  [Paine]					},
		{ 36,  [Rochester_Instrument_Systems] 		},
		{ 37,  [Ronan]					},
		{ 38,  [Rosemount]				},
		{ 39,  [Peek_Measurement]			},
		{ 40,  [Schlumberger]				},
		{ 41,  [Sensall]				},
		{ 42,  [Siemens]				},
		{ 43,  [Camille_Bauer]				},
		{ 44,  [Toshiba]				},
		{ 45,  [Transmation]				},
		{ 46,  [Rosemount_Analytical]			},
		{ 47,  [Valmet]					},
		{ 48,  [Valtek]					},
		{ 49,  [Varec]					},
		{ 50,  [Viatran]				},
		{ 51,  [Weed]					},
		{ 52,  [Westinghouse]				},
		{ 53,  [Xomox]					},
		{ 54,  [Yamatake]				},
		{ 55,  [Yokogawa]				},
		{ 56,  [Nuovo_Pignone]				},
		{ 57,  [Promac]					},
		{ 58,  [Exac_Corporation]			},
		{ 59,  [KDG_Mobrey]				},
		{ 60,  [Acrom_Control_System]		 	},
		{ 61,  [Princo]					},
		{ 62,  [Smar]					},
		{ 63,  [Foxboro_Eckardt]			},
		{ 64,  [Measurement_Technology]			},
		{ 65,  [Applied_System_Technologies]		},
		{ 66,  [Samson]					},
		{ 67,  [Sparling_Instruments]			},
		{ 68,  [Fireye]					},
		{ 69,  [Krohne]					},
		{ 70,  [Betz_Equipment]				},
		{ 71,  [Druck]					},
		{ 72,  [SOR]					},
		{ 73,  [Elcon_Instruments]			},
		{ 74,  [EMCO]					},
		{ 75,  [Termiflex]				},
		{ 76,  [VAF_Instruments]			},
		{ 77,  [Westlock_Controls]			},
		{ 78,  [Drexelbrook]				},
		{ 79,  [saab_tank_control]			},
		{ 80,  [K_TEK]					},
		{ 81,  [Flowdata]				},
		{ 82,  [Draeger]				},
		{ 83,  [Raytek]					},
		{ 84,  [Meridian_Instruments]			},
		{ 85,  [BTG]					},
		{ 86,  [Magnetrol]				},
		{ 87,  [Neles_Controls]				},
		{ 88,  [Milltronics]				},
		{ 89,  [HELIOS]					},
		{ 90,  [Anderson_Instrument_Company]		},
		{ 91,  [INOR]					},
		{ 92,  [ROBERTSHAW]				},
		{ 93,  [PEPPERL_FUCHS]				},
		{ 94,  [ACCUTECH]				},
		{ 95,  [Flow_Measurement]			},
		{ 96,  [KAMSTRUP]				},
		{ 97,  [Knick]					},
		{ 98,  [VEGA]					},
		{ 99,  [MTS_SYS_CORPS_SENSORS]			},
		{ 100, [Oval]					},
		{ 101, [Masoneilan_DRESSER]			},
		{ 102, [Besta]					},
		{ 103, [Ohmart]					},
		{ 104, [Harold_Beck_and_Sons]			},
		{ 105, [rittmeyer_instrumentation]		},
		{ 106, [rossel_messtechnik]			},
		{ 107, [WIKA]					},
		{ 108, [Bopp_and_Reuther_Heinrichs]		},
		{ 109, [pr_eletronics]				},
		{ 110, [jordan_controls]			},
		{ 111, [valcom]					},
		{ 112, [us_electric_motors]			}, 
		{ 113, [apparatebau_hundsbach]			},
		{ 250, [not_used]				},
		{ 251, [none]					},
		{ 252, [unknown]				},
		{ 253, [special]				},
		{ 280, "BEKA Associates Ltd"			}
	}
	HANDLING	READ;
}

VARIABLE phys_DEVICE_ID
{
	LABEL		[phys_device_type];
	HELP		[phys_device_type_help];
	CLASS		CONTAINED;
	TYPE		ASCII (16);
	HANDLING	READ;
}

VARIABLE phys_SERIAL_NUMBER
{
	LABEL		[phys_serial_num];
	HELP		[phys_device_ser_num_help];
	CLASS		CONTAINED;
	TYPE		ASCII (16);
	HANDLING	READ;
}

VARIABLE phys_DIAGNOSIS
{
	LABEL		[phys_diagnosis];
	HELP		[phys_diagnosis_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (4)
	{
	     DEFAULT_VALUE	0x0000;
		{	DIA_OK,				[dia_OK],					[dia_OK_help]					},
		{	DIA_HW_ELECTR,			[dia_HW_ELECTR],			[dia_HW_ELECTR_help]			},
		{	DIA_HW_MECH,			[dia_HW_MECH],				[dia_HW_MECH_help]				},
		{	DIA_TEMP_MOTOR,			[dia_TEMP_MOTOR],			[dia_TEMP_MOTOR_help]			},
		{	DIA_TEMP_ELECTR,		[dia_TEMP_ELECTR],			[dia_TEMP_ELECTR_help]			},
		{	DIA_MEM_CHKSUM,			[dia_MEM_CHKSUM],			[dia_MEM_CHKSUM_help]			},
		{	DIA_MEASUREMENT,		[dia_MEASUREMENT],			[dia_MEASUREMENT_help]			},
		{	DIA_NOT_INIT,			[dia_NOT_INIT],				[dia_NOT_INIT_help]				},
		{	DIA_INIT_ERR,			[dia_INIT_ERR],				[dia_INIT_ERR_help]				},
		{	DIA_ZERO_ERR,			[dia_ZERO_ERR],				[dia_ZERO_ERR_help]				},
		{	DIA_SUPPLY,				[dia_SUPPLY],				[dia_SUPPLY_help]				},
		{	DIA_CONF_INVAL,			[dia_CONF_INVAL],			[dia_CONF_INVAL_help]			},
		{	DIA_WARMSTART,			[dia_WARMSTART],			[dia_WARMSTART_help]			},
		{	DIA_COLDSTART,			[dia_COLDSTART],			[dia_COLDSTART_help]			},
		{	DIA_MAINTENANCE,		[dia_MAINTENANCE],			[dia_MAINTENANCE_help]			},
		{	DIA_CHARACT,			[dia_CHARACT],				[dia_CHARACT_help]				},
		{	EXTENSION_AVAILABLE,	[dia_EXTENSION_AVAILABLE],	[dia_EXTENSION_AVAILABLE_help]	}  
	}
	HANDLING	READ;
}

VARIABLE phys_DIAGNOSIS_EXT_01
{
	LABEL		[phys_diagnosis_extension];
	HELP		[phys_diagnosis_extension_help];
	CLASS		CONTAINED & DYNAMIC;
   	TYPE		BIT_ENUMERATED (4)
   	{
		{	DIA_OK,	 [dia_OK],[dia_OK_help]	}
   	}
	HANDLING	READ;
}

VARIABLE phys_DIAGNOSIS_EXT_02
{
	LABEL		[phys_diagnosis_extension];
	HELP		[phys_diagnosis_extension_help];
	CLASS		CONTAINED & DYNAMIC;
   	TYPE		BIT_ENUMERATED (2)
   	{
		{	DIA_OK,	 [dia_OK],[dia_OK_help]	}
   	}
	HANDLING	READ;
}

VARIABLE phys_DIAGNOSIS_MASK
{
	LABEL		[phys_diagnosis_mask];
	HELP		[phys_diagnosis_mask_help];
	CLASS		CONTAINED;
	TYPE		BIT_ENUMERATED (4)
	{
		{	DIA_HW_ELECTR,			[dia_HW_ELECTR],			[dia_HW_ELECTR_help]			},
		{	DIA_HW_MECH,			[dia_HW_MECH],				[dia_HW_MECH_help]				},
		{	DIA_TEMP_MOTOR,			[dia_TEMP_MOTOR],			[dia_TEMP_MOTOR_help]			},
		{	DIA_TEMP_ELECTR,		[dia_TEMP_ELECTR],			[dia_TEMP_ELECTR_help]			},
		{	DIA_MEM_CHKSUM,			[dia_MEM_CHKSUM],			[dia_MEM_CHKSUM_help]			},
		{	DIA_MEASUREMENT,		[dia_MEASUREMENT],			[dia_MEASUREMENT_help]			},
		{	DIA_NOT_INIT,			[dia_NOT_INIT],				[dia_NOT_INIT_help]				},
		{	DIA_INIT_ERR,			[dia_INIT_ERR],				[dia_INIT_ERR_help]				},
		{	DIA_ZERO_ERR,			[dia_ZERO_ERR],				[dia_ZERO_ERR_help]				},
		{	DIA_SUPPLY,				[dia_SUPPLY],				[dia_SUPPLY_help]				},
		{	DIA_CONF_INVAL,			[dia_CONF_INVAL],			[dia_CONF_INVAL_help]			},
		{	DIA_WARMSTART,			[dia_WARMSTART],			[dia_WARMSTART_help]			},
		{	DIA_COLDSTART,			[dia_COLDSTART],			[dia_COLDSTART_help]			},
		{	DIA_MAINTENANCE,		[dia_MAINTENANCE],			[dia_MAINTENANCE_help]			},
		{	DIA_CHARACT,			[dia_CHARACT],				[dia_CHARACT_help]				},
		{	EXTENSION_AVAILABLE,	[dia_EXTENSION_AVAILABLE],	[dia_EXTENSION_AVAILABLE_help]	}
	}
	HANDLING	READ;
}

VARIABLE phys_DIAGNOSIS_MASK_EXT_01
{
  LABEL		[phys_diagnosis_extension_mask];
  HELP		[phys_diagnosis_extension_mask_help];
  CLASS		CONTAINED;
  TYPE		BIT_ENUMERATED (4)
   	{
		{	DIA_OK,	 [dia_OK],[dia_OK_help]	}
   	}
	
  HANDLING	READ;
}

VARIABLE phys_DIAGNOSIS_MASK_EXT_02
{
  LABEL		[phys_diagnosis_extension_mask];
  HELP		[phys_diagnosis_extension_mask_help];
  CLASS		CONTAINED;
  TYPE		BIT_ENUMERATED (2)
  {
		{	DIA_OK,	 [dia_OK],[dia_OK_help]	}
  }
  HANDLING	READ;
}

VARIABLE phys_CERTIFICATION
{
	LABEL		[phys_device_certification];
	HELP		[phys_device_certification_help];
	CLASS		CONTAINED;
	TYPE		ASCII (32)
	{
		DEFAULT_VALUE	"";
	}
	HANDLING	READ;
}

VARIABLE phys_WRITE_LOCKING
{
	LABEL		[phys_write_locking];
	HELP		[phys_write_locking_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	2457;
		{ 2457,		[off]	},
		{ 0,		[on]	}
	}
	HANDLING	READ & WRITE;
}

VARIABLE phys_FACTORY_RESET
{
	LABEL		[phys_factory_reset];
	HELP		[phys_factory_reset_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
 		DEFAULT_VALUE	0;
		{ 0,		[no_function]			},
		{ 1,		[factory_reset_PARAMS]	},
		{ 2506,		[phys_device_reset_cmd]	},
		{ 2712,		[factory_reset_ADDRESS]	}
	}
	HANDLING	READ & WRITE;
}

VARIABLE phys_DESCRIPTION
{
	LABEL		[phys_descriptor];
	HELP		[phys_descriptor_help];
	CLASS		CONTAINED;
	TYPE		ASCII (32)
	{
		DEFAULT_VALUE "";
	}
	HANDLING	READ & WRITE;
}

VARIABLE phys_DEVICE_MESSAGE
{
	LABEL		[phys_message];
	HELP		[phys_message_help];
	CLASS		CONTAINED;
	TYPE		ASCII (32)
	{
		DEFAULT_VALUE "";
	}
	HANDLING	READ & WRITE;
}

VARIABLE phys_INSTALL_DATE
{
	LABEL		[phys_install_date];
	HELP		[phys_install_date_help];
	CLASS		CONTAINED;
	TYPE		ASCII (16)
	{
		DEFAULT_VALUE "";
	}
	HANDLING	READ & WRITE;
}

VARIABLE phys_LOCAL_OP_ENABLED
{
	LABEL		[beka_localop];
	HELP		[beka_localop];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		{   0,"Disabled"},
		{   1,"Enabled"}
	}
	HANDLING	READ & WRITE;
}

VARIABLE phys_IDENT_NUMBER
{
	LABEL		[phys_ident_number];
	HELP		[phys_ident_number_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	1;
		{	0,	[phys_ident_number_PROFILE]		},
		{	1,	[phys_ident_number_MANUFACURER]	}
	}
	HANDLING	READ & WRITE;
}

/*
VARIABLE phys_HW_WRITE_PROTECTION
{
	LABEL		[phys_hw_write_protection];
	HELP		[phys_hw_write_protection_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ;
}
*/

/**********************************************************************/
/*****	COMMANDS Physical Block
/**********************************************************************/

COMMAND read_phys_BLOCK
{
	BLOCK phys_BLOCK;
	INDEX 0;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_BLK_RESERVE,
			phys_BLK_OBJECT,
			phys_BLK_PARENT_CLASS,
			phys_BLK_CLASS,
			phys_BLK_DD_REFRENCE,
			phys_BLK_DD_REV,
			phys_BLK_PROFILE,
			phys_BLK_PROFILE_REV,
			phys_BLK_EXECUTION_TIME,
			phys_BLK_NUM_PARAMETERS,
			phys_BLK_INDEX_VIEW_1,
			phys_BLK_NUM_VIEW_LISTS
		}
	}
}

COMMAND read_phys_STATIC_REVISION
{
	BLOCK phys_BLOCK;
	INDEX 1;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_STATIC_REVISION
		}
	}
}

COMMAND read_phys_TAG_DESCRIPTION
{
	BLOCK phys_BLOCK;
	INDEX 2;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_TAG_DESCRIPTION
		}
	}
}

COMMAND write_phys_TAG_DESCRIPTION
{
	BLOCK phys_BLOCK;
	INDEX 2;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			phys_TAG_DESCRIPTION
		}
		REPLY
		{
		}
	}
}

COMMAND read_phys_STRATEGY
{
	BLOCK phys_BLOCK;
	INDEX 3;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_STRATEGY
		}
	}
}

COMMAND write_phys_STRATEGY
{
	BLOCK phys_BLOCK;
	INDEX 3;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			phys_STRATEGY
		}
		REPLY
		{
		}
	}
}

COMMAND read_phys_ALERT_KEY
{
	BLOCK phys_BLOCK;
	INDEX 4;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_ALERT_KEY
		}
	}
}

COMMAND write_phys_ALERT_KEY
{
	BLOCK phys_BLOCK;
	INDEX 4;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			phys_ALERT_KEY
		}
		REPLY
		{
		}
	}
}

COMMAND read_phys_TARGET_MODE
{
	BLOCK phys_BLOCK;
	INDEX 5;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_TARGET_MODE
		}
	}
}

COMMAND write_phys_TARGET_MODE
{
	BLOCK phys_BLOCK;
	INDEX 5;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			phys_TARGET_MODE
		}
		REPLY
		{
		}
	}
}

COMMAND read_phys_MODE
{
	BLOCK phys_BLOCK;
	INDEX 6;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_ACTUAL_MODE,
			phys_PERMITTED_MODE,
			phys_NORMAL_MODE
		}
	}
}

COMMAND read_phys_ALARM_SUM
{
	BLOCK phys_BLOCK;
	INDEX 7;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_CURRENT_STATE_ALARM_SUM,
			phys_UNACKNOWLEDGED_STATE_ALARM_SUM,
			phys_UNREPORTED_STATE_ALARM_SUM,
			phys_DISABLED_STATE_ALARM_SUM
		}
	}
}

COMMAND read_phys_SOFTWARE_REVISION
{
	BLOCK phys_BLOCK;
	INDEX 8;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_SOFTWARE_REVISION
		}
	}
}

COMMAND read_phys_HARDWARE_REVISION
{
	BLOCK phys_BLOCK;
	INDEX 9;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_HARDWARE_REVISION
		}
	}
}

COMMAND read_phys_DEVICE_MAN_ID
{
	BLOCK phys_BLOCK;
	INDEX 10;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_DEVICE_MAN_ID
		}
	}
}

COMMAND read_phys_DEVICE_ID
{
	BLOCK phys_BLOCK;
	INDEX 11;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_DEVICE_ID
		}
	}
}

/*
COMMAND write_phys_DEVICE_ID
{
	BLOCK phys_BLOCK;
	INDEX 11;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			phys_DEVICE_ID
		}
		REPLY
		{
		}
	}
}
*/			//fbi

COMMAND read_phys_SERIAL_NUMBER
{
	BLOCK phys_BLOCK;
	INDEX 12;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_SERIAL_NUMBER
		}
	}
}

COMMAND read_phys_DIAGNOSIS
{
	BLOCK phys_BLOCK;
	INDEX 13;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_DIAGNOSIS
		}
	}
}

COMMAND read_phys_DIAGNOSIS_EXT
{
	BLOCK phys_BLOCK;
	INDEX 14;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_DIAGNOSIS_EXT_01,
			phys_DIAGNOSIS_EXT_02
		}
	}
}

COMMAND read_phys_DIAGNOSIS_MASK
{
	BLOCK phys_BLOCK;
	INDEX 15;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_DIAGNOSIS_MASK
		}
	}
}

COMMAND read_phys_DIAGNOSIS_MASK_EXT
{
	BLOCK phys_BLOCK;
	INDEX 16;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_DIAGNOSIS_MASK_EXT_01,
			phys_DIAGNOSIS_MASK_EXT_02
		}
	}
}

COMMAND read_phys_CERTIFICATION
{
	BLOCK phys_BLOCK;
	INDEX 17;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_CERTIFICATION
		}
	}
}

COMMAND read_phys_WRITE_LOCKING
{
	BLOCK phys_BLOCK;
	INDEX 18;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_WRITE_LOCKING
		}
	}
}

COMMAND write_phys_WRITE_LOCKING
{
	BLOCK phys_BLOCK;
	INDEX 18;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			phys_WRITE_LOCKING
		}
		REPLY
		{
		}
	}
}

COMMAND read_phys_FACTORY_RESET
{
	BLOCK phys_BLOCK;
	INDEX 19;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_FACTORY_RESET
		}
	}
}

COMMAND write_phys_FACTORY_RESET
{
	BLOCK phys_BLOCK;
	INDEX 19;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			phys_FACTORY_RESET
		}
		REPLY
		{
		}
	}
}

COMMAND read_phys_DESCRIPTION
{
	BLOCK phys_BLOCK;
	INDEX 20;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_DESCRIPTION
		}
	}
}

COMMAND write_phys_DESCRIPTION
{
	BLOCK phys_BLOCK;
	INDEX 20;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			phys_DESCRIPTION
		}
		REPLY
		{
		}
	}
}

COMMAND read_phys_DEVICE_MESSAGE
{
	BLOCK phys_BLOCK;
	INDEX 21;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_DEVICE_MESSAGE
		}
	}
}

COMMAND write_phys_DEVICE_MESSAGE
{
	BLOCK phys_BLOCK;
	INDEX 21;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			phys_DEVICE_MESSAGE
		}
		REPLY
		{
		}
	}
}

COMMAND read_phys_INSTALL_DATE
{
	BLOCK phys_BLOCK;
	INDEX 22;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_INSTALL_DATE
		}
	}
}

COMMAND write_phys_INSTALL_DATE
{
	BLOCK phys_BLOCK;
	INDEX 22;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			phys_INSTALL_DATE
		}
		REPLY
		{
		}
	}
}

COMMAND read_phys_LOCAL_OP_ENABLED
{
	BLOCK phys_BLOCK;
	INDEX 23;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_LOCAL_OP_ENABLED
		}
	}
}

COMMAND write_phys_LOCAL_OP_ENABLED
{
	BLOCK phys_BLOCK;
	INDEX 23;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			phys_LOCAL_OP_ENABLED
		}
		REPLY
		{
		}
	}
}

COMMAND read_phys_IDENT_NUMBER
{
	BLOCK phys_BLOCK;
	INDEX 24;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_IDENT_NUMBER
		}
	}
}

COMMAND write_phys_IDENT_NUMBER
{
	BLOCK phys_BLOCK;
	INDEX 24;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			phys_IDENT_NUMBER
		}
		REPLY
		{
		}
	}
}


COMMAND read_phys_HW_WRITE_PROTECTION
{
	BLOCK phys_BLOCK;
	INDEX 25;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_HW_WRITE_PROTECTION
		}
	}
}

/**********************************************************************/
/*****	Table: Information - Specialist and Maintenance 
/**********************************************************************/

MENU Table_S_phys
{
	LABEL		[beka_phys];
	ITEMS
	{
        	Table_phys_tbblock,
        	phys_STATIC_REVISION,
        	phys_TAG_DESCRIPTION,
        	phys_STRATEGY,
        	phys_ALERT_KEY,
        	phys_TARGET_MODE,
        	Table_phys_modeblock,
        	Table_phys_alarmblock
        	phys_SOFTWARE_REVISION,
        	phys_HARDWARE_REVISION,
        	phys_DEVICE_MAN_ID,
        	phys_DEVICE_ID,
        	phys_SERIAL_NUMBER,
        	phys_DIAGNOSIS,
        	phys_DIAGNOSIS_EXT_1,
        	phys_DIAGNOSIS_EXT_2,
        	phys_DIAGNOSIS_MASK,
        	phys_DIAGNOSIS_MASK_EXT_1,
        	phys_DIAGNOSIS_MASK_EXT_2,
        	phys_CERTIFICATION,
        	phys_WRITE_LOCKING		(READ_ONLY),
        	phys_DESCRIPTION,
        	phys_DEVICE_MESSAGE,
        	phys_INSTALL_DATE,
        	phys_LOCAL_OP_ENABLED,
        	phys_IDENT_NUMBER,
        	phys_HW_WRITE_PROTECTION
        	
	}
}

MENU Table_M_phys
{
	LABEL		[beka_phys];
	ITEMS
	{
        	Table_phys_tbblock,
        	phys_STATIC_REVISION	 	(READ_ONLY),
        	phys_TAG_DESCRIPTION	 	(READ_ONLY),
        	phys_STRATEGY 			(READ_ONLY),
        	phys_ALERT_KEY 			(READ_ONLY),
        	phys_TARGET_MODE 		(READ_ONLY),
        	Table_phys_modeblock,
        	Table_phys_alarmblock
        	phys_SOFTWARE_REVISION,
        	phys_HARDWARE_REVISION,
        	phys_DEVICE_MAN_ID,
        	phys_DEVICE_ID,
        	phys_SERIAL_NUMBER,
        	phys_DIAGNOSIS,
        	phys_DIAGNOSIS_EXT_1,
        	phys_DIAGNOSIS_EXT_2,
        	phys_DIAGNOSIS_MASK,
        	phys_DIAGNOSIS_MASK_EXT_1,
        	phys_DIAGNOSIS_MASK_EXT_2,
        	phys_CERTIFICATION,
        	phys_WRITE_LOCKING		(READ_ONLY),
        	phys_FACTORY_RESET		(READ_ONLY),
        	phys_DESCRIPTION		(READ_ONLY),
        	phys_DEVICE_MESSAGE		(READ_ONLY),
        	phys_INSTALL_DATE		(READ_ONLY),
        	phys_LOCAL_OP_ENABLED		(READ_ONLY),
        	phys_IDENT_NUMBER		(READ_ONLY),
        	phys_HW_WRITE_PROTECTION
	}
}

MENU Table_phys_tbblock
{
	LABEL		[beka_block_characteristics];
	ITEMS
	{
		phys_BLK_RESERVE,
		phys_BLK_OBJECT,
		phys_BLK_PARENT_CLASS,
		phys_BLK_CLASS,
		phys_BLK_DD_REFERENCE,
		phys_BLK_DD_REV,
		phys_BLK_PROFILE,
		phys_BLK_PROFILE_REV,
		phys_BLK_EXECUTION_TIME,
		phys_BLK_NUM_PARAMETERS,
		phys_BLK_INDEX_VIEW_1,
		phys_BLK_NUM_VIEW_LISTS
	}
}

MENU Table_phys_modeblock
{
	LABEL		[beka_mode_block];
	ITEMS
	{
		phys_ACTUAL_MODE,
		phys_PERMITTED_MODE,
		phys_NORMAL_MODE,
	}
}


MENU Table_phys_alarmblock
{
	LABEL		[beka_alarm_summary];
	ITEMS
	{
		phys_CURRENT_STATE_ALARM_SUM,
		phys_UNACKNOWLEDGED_STATE_ALARM_SUM,
		phys_UNREPORTED_STATE_ALARM_SUM,
		phys_DISABLED_STATE_ALARM_SUM
	}
}
