/***********************************************************************/
/***********************************************************************/
/**                                                              
/** Copyright (C) BEKA Associates Ltd (2005). All Rights Reserved    
/**                                                                   
/** Device        : BA488CF                              
/** Communication : PROFIBUS PA                                       
/** Description   : PROFIBUS PA EDDL for BA488CF  		 
/**  		    Graphics Transducer Block Varaibles and Commands            
/**
/** History       : M.P.Wilson 04/03/2005 first created
/**  		  : M.P.Wilson 29/04/2005 Block View Added
/**	            M.P.Wilson 04/05/2005 View Menus added 		
/**
/***********************************************************************/
/***********************************************************************/


/***********************************************************************/
/*****	VARIABLES GRAPHICS Transducer Block
/***********************************************************************/

VARIABLE graphics_BLK_RESERVE
{
	LABEL		[blk_reserved];
	HELP		[blk_reserved_help];
	CLASS		CONTAINED;
  	TYPE		ENUMERATED(1)
	{
		DEFAULT_VALUE	250;
		{	250,	[not_used]		}
	}
	HANDLING	READ;
}

VARIABLE graphics_BLK_OBJECT
{
	LABEL		[blk_block_object];
	HELP		[blk_block_object_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		{	3,	[blk_block_object_TRANSDUCER]	}
	}
	HANDLING	READ;
}

VARIABLE graphics_BLK_PARENT_CLASS
{
	LABEL		[blk_parent_class];
	HELP		[TB_blk_parent_class_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED(1)
	{
		{ 0xf4, "Transducer" }
	}
	HANDLING	READ;
}

VARIABLE graphics_BLK_CLASS
{
	LABEL		[blk_class];
	HELP		[TB_blk_class_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED(1)
	{
		{	250,	[not_used] 					},
		{	251,	[none]						},
		{	252,	[unknown]					},
		{	253,	[special]					}
	}
	HANDLING	READ;
}

VARIABLE graphics_BLK_DD_REFRENCE
{
	LABEL		[blk_dd_reference];
	HELP		[blk_dd_reference_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (4);
	HANDLING	READ;
}

VARIABLE graphics_BLK_DD_REV
{
	LABEL		[blk_dd_rev];
	HELP		[blk_dd_rev_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER(2);
	HANDLING	READ;
}

VARIABLE graphics_BLK_PROFILE
{
	LABEL		[blk_profile];
	HELP		[blk_profile_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	0x4002;
		{ 0x4001,	[blk_profile_PA_COMPACT_A]	},
		{ 0x4002,	[blk_profile_PA_COMPACT_B]	},
		{ 0x4081,	[blk_profile_PA_SIMPLE_A]	},
		{ 0x4082,	[blk_profile_PA_SIMPLE_B]	}
	}
	HANDLING	READ;
}

VARIABLE graphics_BLK_PROFILE_REV
{
	LABEL		[blk_profile_rev];
	HELP		[blk_profile_rev_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	0x0300;
		{	0x0300,	"3.0"	}
	}
	HANDLING	READ;
}

VARIABLE graphics_BLK_EXECUTION_TIME
{
	LABEL		[blk_execution_time];
	HELP		[blk_execution_time_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER(1)
	{
		DEFAULT_VALUE	0;
	}
	HANDLING	READ;
}

VARIABLE graphics_BLK_NUM_PARAMETERS
{
	LABEL		[blk_num_parameters];
	HELP		[blk_num_parameters_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
}

VARIABLE graphics_BLK_INDEX_VIEW_1
{
	LABEL		[blk_index_view_1];
	HELP		[blk_index_view_1_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
}

VARIABLE graphics_BLK_NUM_VIEW_LISTS
{
	LABEL		[blk_num_view_lists];
	HELP		[blk_num_view_lists_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ;
}

VARIABLE graphics_STATIC_REVISION
{
	LABEL		[st_rev];
	HELP		[st_rev_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE	0;
	}
	HANDLING	READ;
}

VARIABLE graphics_TAG_DESCRIPTION
{
	LABEL		[tag_desc];		
	HELP		[tag_desc_help];
	CLASS		CONTAINED;
	TYPE		ASCII (32)
	{
		DEFAULT_VALUE "";
	}
	HANDLING	READ & WRITE;
}

VARIABLE graphics_STRATEGY
{
	LABEL		[strategy];		
	HELP		[strategy_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ & WRITE;
}

VARIABLE graphics_ALERT_KEY
{
	LABEL		[alert_key];		
	HELP		[alert_key_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ & WRITE;
}

VARIABLE graphics_TARGET_MODE
{
	LABEL	  	[target_mode];		
	HELP		[target_mode_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
	   DEFAULT_VALUE	0x08;
		{	0x08,	[mode_AUTO]				}
		{	0x80,	[mode_OUT_OF_SERVICE]	}

	}
	HANDLING	READ & WRITE;
}

VARIABLE graphics_ACTUAL_MODE
{
	LABEL		[actual_mode];		
	HELP		[actual_mode_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE 0x08 ;
//		{	0x02,	[mode_RCAS]				},
		{	0x08,	[mode_AUTO]				}
//		{	0x10,	[mode_MAN]				},
//		{	0x20,	[mode_LO]				},
		{	0x80,	[mode_OUT_OF_SERVICE]	}
	}
	HANDLING	READ;
}

VARIABLE graphics_PERMITTED_MODE
{
	LABEL		[permitted_mode];		
	HELP		[permitted_mode_help];
	CLASS		CONTAINED;
	TYPE		BIT_ENUMERATED (1)
	{
//		DEFAULT_VALUE	0x88;
		DEFAULT_VALUE	0x08;
//		{	0x02,	[mode_RCAS]				},
		{	0x08,	[mode_AUTO]				}
//		{	0x10,	[mode_MAN]				},
//		{	0x20,	[mode_LO]				},
		{	0x80,	[mode_OUT_OF_SERVICE]	}
	}
	HANDLING	READ;
}

VARIABLE graphics_NORMAL_MODE
{
	LABEL		[normal_mode];		
	HELP		[normal_mode_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0x08;
		{	0x02,	[mode_RCAS]				},
		{	0x08,	[mode_AUTO]				},
		{	0x10,	[mode_MAN]				},
		{	0x20,	[mode_LO]				},
		{	0x80,	[mode_OUT_OF_SERVICE]	}
	}
	HANDLING	READ;
}

VARIABLE graphics_CURRENT_STATE_ALARM_SUM
{
	LABEL		[current_state_alarm_sum];		
	HELP		[current_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		DEFAULT_VALUE	0x0000; 
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE graphics_UNACKNOWLEDGED_STATE_ALARM_SUM
{
	LABEL		[unacknowledged_state_alarm_sum];		
	HELP		[unacknowledged_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		DEFAULT_VALUE	0x0000; 
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE graphics_UNREPORTED_STATE_ALARM_SUM
{
	LABEL		[unreported_state_alarm_sum];		
	HELP		[unreported_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		DEFAULT_VALUE	0x0000; 
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE graphics_DISABLED_STATE_ALARM_SUM
{
	LABEL		[disabled_state_alarm_sum];		
	HELP		[disabled_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		DEFAULT_VALUE	0x0000; 
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE graphics_command_string
{
	LABEL 	 "Command Data";
	HELP 	 "Used to send commands to the text display";
	CLASS 	 CONTAINED & DYNAMIC;
	TYPE	 ASCII (118);
	HANDLING READ & WRITE;
}

VARIABLE graphics_graphics_data
{
	LABEL 	 "Graphics Data";
	HELP 	 "Used to send graphics data to the text display";
	CLASS 	 CONTAINED & DYNAMIC;
	TYPE	 ASCII (118);
	HANDLING READ & WRITE;
}		
VARIABLE graphics_command_id
{
	LABEL 	 "Command ID";
	HELP 	 "Returns value of COMMAND ID";
	CLASS 	 CONTAINED;
	TYPE	 UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE 0;
	}
	HANDLING READ & WRITE;
}		

VARIABLE graphics_result_id
{
	LABEL 	 "Result ID";
	HELP 	 "Returns value of Result ID";
	CLASS 	 CONTAINED & DYNAMIC;
	TYPE	 UNSIGNED_INTEGER (2);
	HANDLING READ;
}		

VARIABLE graphics_result
{
	LABEL 	 "Result";
	HELP 	 "Returns the result of the last command";
	CLASS 	 CONTAINED & DYNAMIC;
	TYPE	 ENUMERATED (1)
	{
		DEFAULT_VALUE 8;
		{	0, "No Error"	          },
		{	1, "Parameter Error"	  },
		{	2, "Command Error"	  },
		{	4, "Unit In Config Menus" },
		{	8, "No Command Yet"	  }
	}
	HANDLING READ;
}		

VARIABLE graphics_key_status
{
	LABEL 	 "Key Status";
	HELP 	 "Returns value of Key pressed";
	CLASS 	 CONTAINED & DYNAMIC;
	TYPE	 UNSIGNED_INTEGER (1);
	HANDLING READ;
}		

VARIABLE graphics_output_status
{
	LABEL 	 "Output Status";
	HELP 	 "Returns value of the Outputs";
	CLASS 	 CONTAINED & DYNAMIC;
	TYPE	 UNSIGNED_INTEGER (1)
	{
		DEFAULT_VALUE 0;
	}
	HANDLING READ & WRITE;
}

/**********************************************************************/
/*****	COMMANDS Graphics Block
/**********************************************************************/

COMMAND read_graphics_BLOCK
{
	BLOCK graphics_BLOCK;
	INDEX 0;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			graphics_BLK_RESERVE,
			graphics_BLK_OBJECT,
			graphics_BLK_PARENT_CLASS,
			graphics_BLK_CLASS,
			graphics_BLK_DD_REFRENCE,
			graphics_BLK_DD_REV,
			graphics_BLK_PROFILE,
			graphics_BLK_PROFILE_REV,
			graphics_BLK_EXECUTION_TIME,
			graphics_BLK_NUM_PARAMETERS,
			graphics_BLK_INDEX_VIEW_1,
			graphics_BLK_NUM_VIEW_LISTS
		}
	}
}

COMMAND read_graphics_STATIC_REVISION
{
	BLOCK graphics_BLOCK;
	INDEX 1;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			graphics_STATIC_REVISION
		}
	}
}

COMMAND read_graphics_TAG_DESCRIPTION
{
	BLOCK graphics_BLOCK;
	INDEX 2;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			graphics_TAG_DESCRIPTION
		}
	}
}

COMMAND write_graphics_TAG_DESCRIPTION
{
	BLOCK graphics_BLOCK;
	INDEX 2;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			graphics_TAG_DESCRIPTION
		}
		REPLY
		{
		}
	}
}

COMMAND read_graphics_STRATEGY
{
	BLOCK graphics_BLOCK;
	INDEX 3;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			graphics_STRATEGY
		}
	}
}

COMMAND write_graphics_STRATEGY
{
	BLOCK graphics_BLOCK;
	INDEX 3;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			graphics_STRATEGY
		}
		REPLY
		{
		}
	}
}

COMMAND read_graphics_ALERT_KEY
{
	BLOCK graphics_BLOCK;
	INDEX 4;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			graphics_ALERT_KEY
		}
	}
}

COMMAND write_graphics_ALERT_KEY
{
	BLOCK graphics_BLOCK;
	INDEX 4;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			graphics_ALERT_KEY
		}
		REPLY
		{
		}
	}
}

COMMAND read_graphics_TARGET_MODE
{
	BLOCK graphics_BLOCK;
	INDEX 5;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			graphics_TARGET_MODE
		}
	}
}

COMMAND write_graphics_TARGET_MODE
{
	BLOCK graphics_BLOCK;
	INDEX 5;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			graphics_TARGET_MODE
		}
		REPLY
		{
		}
	}
}

COMMAND read_graphics_MODE
{
	BLOCK graphics_BLOCK;
	INDEX 6;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			graphics_ACTUAL_MODE,
			graphics_PERMITTED_MODE,
			graphics_NORMAL_MODE
		}
	}
}

COMMAND read_graphics_ALARM_SUM
{
	BLOCK graphics_BLOCK;
	INDEX 7;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			graphics_CURRENT_STATE_ALARM_SUM,
			graphics_UNACKNOWLEDGED_STATE_ALARM_SUM,
			graphics_UNREPORTED_STATE_ALARM_SUM,
			graphics_DISABLED_STATE_ALARM_SUM
		}
	}
}

COMMAND read_graphics_command_string
{
	BLOCK graphics_BLOCK;
	INDEX	8;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			graphics_command_string
		}
		
	}
}

COMMAND write_graphics_command_string
{
	BLOCK graphics_BLOCK;
	INDEX	8;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			graphics_command_string
		}
		REPLY
		{
		}
		
	}
}

COMMAND read_graphics_graphics_data
{
	BLOCK graphics_BLOCK;
	INDEX	9;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			graphics_graphics_data
		}
		
	}
}

COMMAND write_graphics_graphics_data
{
	BLOCK graphics_BLOCK;
	INDEX	9;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			graphics_graphics_data
		}
		REPLY
		{
		}
		
	}
}

COMMAND read_graphics_command_id
{
	BLOCK graphics_BLOCK;
	INDEX	10;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			graphics_command_id
		}
		
	}
}

COMMAND write_graphics_command_id
{
	BLOCK graphics_BLOCK;
	INDEX	10;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			graphics_command_id
		}
		REPLY
		{
		}
		
	}
}

COMMAND read_graphics_result_id
{
	BLOCK graphics_BLOCK;
	INDEX	11;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			graphics_result_id
		}
		
	}
}
	  
COMMAND read_graphics_result
{
	BLOCK graphics_BLOCK;
	INDEX	12;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			graphics_result
		}
		
	}
}
	  
COMMAND read_graphics_key_status
{
	BLOCK graphics_BLOCK;
	INDEX	13;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			graphics_key_status
		}
		
	}
}
	  
COMMAND read_graphics_output_status
{
	BLOCK graphics_BLOCK;
	INDEX	14;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			graphics_output_status
		}
		
	}
}

COMMAND write_graphics_output_Status
{
	BLOCK graphics_BLOCK;
	INDEX	14;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			graphics_output_status
		}
		REPLY
		{
		}
		
	}
}

/**********************************************************************/
/*****	Table: Information - Specialist and Maintenance 
/**********************************************************************/

MENU Table_S_graphics
{
	LABEL		[beka_graphics];
	ITEMS
	{
        	Table_graphics_tbblock,
        	graphics_STATIC_REVISION,
        	graphics_TAG_DESCRIPTION,
        	graphics_STRATEGY,
        	graphics_ALERT_KEY,
        	graphics_TARGET_MODE,
        	Table_graphics_modeblock,
        	Table_graphics_alarmblock,
        	graphics_command_string,
        	graphics_graphic_data,
        	graphics_command_id,
        	graphics_result_id,
        	graphics_result,
        	graphics_key_status,
        	graphics_output_status
	}
}

MENU Table_M_graphics
{
	LABEL		[beka_graphics];
	ITEMS
	{
        	Table_graphics_tbblock,
        	graphics_STATIC_REVISION 	(READ_ONLY),
        	graphics_TAG_DESCRIPTION 	(READ_ONLY),
        	graphics_STRATEGY 		(READ_ONLY),
        	graphics_ALERT_KEY 		(READ_ONLY),
        	graphics_TARGET_MODE 		(READ_ONLY),
        	Table_graphics_modeblock,
        	Table_graphics_alarmblock
        	graphics_command_string		(READ_ONLY),
        	graphics_graphic_data		(READ_ONLY),
        	graphics_command_id		(READ_ONLY),
        	graphics_result_id,
        	graphics_result,
        	graphics_key_status,
        	graphics_output_status		(READ_ONLY)
	}
}

MENU Table_graphics_tbblock
{
	LABEL		[beka_block_characteristics];
	ITEMS
	{
		graphics_BLK_RESERVE,
		graphics_BLK_OBJECT,
		graphics_BLK_PARENT_CLASS,
		graphics_BLK_CLASS,
		graphics_BLK_DD_REFERENCE,
		graphics_BLK_DD_REV,
		graphics_BLK_PROFILE,
		graphics_BLK_PROFILE_REV,
		graphics_BLK_EXECUTION_TIME,
		graphics_BLK_NUM_PARAMETERS,
		graphics_BLK_INDEX_VIEW_1,
		graphics_BLK_NUM_VIEW_LISTS
	}
}

MENU Table_graphics_modeblock
{
	LABEL		[beka_mode_block];
	ITEMS
	{
		graphics_ACTUAL_MODE,
		graphics_PERMITTED_MODE,
		graphics_NORMAL_MODE,
	}
}


MENU Table_graphics_alarmblock
{
	LABEL		[beka_alarm_summary];
	ITEMS
	{
		graphics_CURRENT_STATE_ALARM_SUM,
		graphics_UNACKNOWLEDGED_STATE_ALARM_SUM,
		graphics_UNREPORTED_STATE_ALARM_SUM,
		graphics_DISABLED_STATE_ALARM_SUM
	}
}

MENU graphics_keys
{
	LABEL		"Key Information";
	ITEMS
	{
		graphics_key_status
	}
}

MENU graphics_outputs
{
	LABEL		"Alarm Output Information";
	ITEMS
	{
		graphics_output_status (READ_ONLY)
	}
}


